==> baseui-4.3.0.tgz: package/tooltip/__tests__/stateful-tooltip.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _popover = require("../../popover");

var _index = require("../index");

var _defaultProps = _interopRequireDefault(require("../default-props"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function withoutChildren(props) {
  var shallowCopy = _objectSpread({}, props);

  delete shallowCopy.children;
  return shallowCopy;
}

describe('StatefulTooltip', function () {
  test('basic render', function () {
    function CustomBody() {
      return _react.default.createElement("span", null);
    }

    var props = {
      overrides: {
        Body: CustomBody
      },
      content: jest.fn(),
      initialState: {
        isOpen: true
      },
      onMouseEnterDelay: 100,
      onMouseLeaveDelay: 200,
      onClose: jest.fn(),
      onOpen: jest.fn(),
      placement: _index.PLACEMENT.topLeft,
      showArrow: true,
      stateReducer: jest.fn(),
      triggerType: _index.TRIGGER_TYPE.hover
    };
    var component = (0, _enzyme.shallow)(_react.default.createElement(_index.StatefulTooltip, props, _react.default.createElement("span", null, "Hover me"))); // Should first render a stateful tooltip container

    expect(component).toMatchSnapshot('renders <StatefulContainer/>'); // Should delegate to stateful popover container

    var dive = component.dive();
    expect(dive.type()).toEqual(_popover.StatefulContainer);
    expect(withoutChildren(dive.props())).toEqual(_objectSpread({}, _defaultProps.default, props, {
      dismissOnClickOutside: true,
      dismissOnEsc: true
    })); // But ultimately render a tooltip

    dive = dive.dive();
    expect(dive.type()).toEqual(_index.Tooltip);
    expect(dive).toMatchSnapshot('renders <Tooltip/>');
  });
});

==> baseui-5.10.0.tgz: package/tooltip/__tests__/stateful-tooltip.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _index = require("../../popover/index.js");

var _index2 = require("../index.js");

var _defaultProps = _interopRequireDefault(require("../default-props.js"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function withoutChildren(props) {
  var shallowCopy = _objectSpread({}, props);

  delete shallowCopy.children;
  return shallowCopy;
}

describe('StatefulTooltip', function () {
  test('basic render', function () {
    function CustomBody() {
      return _react.default.createElement("span", null);
    }

    var props = {
      overrides: {
        Body: CustomBody
      },
      content: jest.fn(),
      initialState: {
        isOpen: true
      },
      onMouseEnterDelay: 100,
      onMouseLeaveDelay: 200,
      onClose: jest.fn(),
      onOpen: jest.fn(),
      placement: _index2.PLACEMENT.topLeft,
      showArrow: true,
      stateReducer: jest.fn(),
      triggerType: _index2.TRIGGER_TYPE.hover
    };
    var component = (0, _enzyme.shallow)(_react.default.createElement(_index2.StatefulTooltip, props, _react.default.createElement("span", null, "Hover me"))); // Should first render a stateful tooltip container

    expect(component).toMatchSnapshot('renders <StatefulContainer/>'); // Should delegate to stateful popover container

    var dive = component.dive();
    expect(dive.type()).toEqual(_index.StatefulContainer);
    expect(withoutChildren(dive.props())).toEqual(_objectSpread({}, _defaultProps.default, props, {
      dismissOnClickOutside: true,
      dismissOnEsc: true,
      ignoreBoundary: false
    })); // But ultimately render a tooltip

    dive = dive.dive();
    expect(dive.type()).toEqual(_index2.Tooltip);
    expect(dive).toMatchSnapshot('renders <Tooltip/>');
  });
});
